==> ixnetwork_restpy-0.0.0-py2.py3-none-any.whl: ixnetwork_restpy/testplatform/sessions/ixnetwork/topology/level.py <==
# Copyright 1997 - 2018 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Level(Base):
	"""The Level class encapsulates a system managed level node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Level property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'level'

	def __init__(self, parent):
		super(Level, self).__init__(parent)

	@property
	def NodeCount(self):
		"""Number of Nodes Per Level

		Returns:
			number
		"""
		return self._get_attribute('nodeCount')
	@NodeCount.setter
	def NodeCount(self, value):
		self._set_attribute('nodeCount', value)

	def find(self, NodeCount=None):
		"""Finds and retrieves level data from the server.

		All named parameters support regex and can be used to selectively retrieve level data from the server.
		By default the find method takes no parameters and will retrieve all level data from the server.

		Args:
			NodeCount (number): Number of Nodes Per Level

		Returns:
			self: This instance with matching level data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of level data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the level data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

==> ixnetwork_restpy-0.1.21-py2.py3-none-any.whl: ixnetwork_restpy/testplatform/sessions/ixnetwork/topology/level.py <==
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Level(Base):
	"""The Level class encapsulates a system managed level node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Level property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'level'

	def __init__(self, parent):
		super(Level, self).__init__(parent)

	@property
	def NodeCount(self):
		"""Number of Nodes Per Level

		Returns:
			number
		"""
		return self._get_attribute('nodeCount')
	@NodeCount.setter
	def NodeCount(self, value):
		self._set_attribute('nodeCount', value)

	def find(self, NodeCount=None):
		"""Finds and retrieves level data from the server.

		All named parameters support regex and can be used to selectively retrieve level data from the server.
		By default the find method takes no parameters and will retrieve all level data from the server.

		Args:
			NodeCount (number): Number of Nodes Per Level

		Returns:
			self: This instance with found level data from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def FetchAndUpdateConfigFromCloud(self, Mode):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		Args:
			Arg1 (str(None|/api/v1/sessions/1/ixnetwork/globals?deepchild=*|/api/v1/sessions/1/ixnetwork/topology?deepchild=*)): The method internally set Arg1 to the current href for this instance
			Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		Arg1 = self.href
		return self._execute('FetchAndUpdateConfigFromCloud', payload=locals(), response_object=None)
